/**
 *    @file  rptsample.c
 *   @brief  Basic report without connection to test output format
 *
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  28/10/2024
 *      Revision:  none
 * Last modified:  2024-11-14 18:14
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "rptsample.h"
#include "clustercon.h"
#include "json.h"
#include "csv.h"
#include <string.h>

/* To refactor in a report common file */
static void csv_addjsonfield(FILE* reportfile, const cJSON* json, char* fieldname) {
    char* text = json2text(cJSON_GetObjectItemCaseSensitive(json, fieldname));
    csv_addfield(reportfile,text);
    free(text);
}

void report_sample_header(FILE* reportfile) {
    fprintf(reportfile,
            "field1,field2,field3\r\n"
           );
}

void report_sample(FILE* reportfile, const cluster_t* cluster) {
    cJSON* samples_json;
    (void)cluster;

    samples_json = cJSON_Parse("["
                               "{\"field1\":\"value1\",\"field2\":\"value 2\",\"field3\":\" value3\"},"
                               "{\"field1\":\"value4 \",\"field2\":\"value,5\",\"field3\":\"value\\\"6\\\"\"}"
                               "]");
    const cJSON* sample_json;
    cJSON_ArrayForEach(sample_json, samples_json) {
        csv_addfield(reportfile,cluster->host);
        csv_addjsonfield(reportfile, sample_json, "field1");
        csv_addjsonfield(reportfile, sample_json, "field2");
        csv_addjsonfield(reportfile, sample_json, "field3");

        csv_addline(reportfile);
    }
    cJSON_Delete(samples_json);
}
/* vim: set tw=80: */
