/**   @file  suite_clustercon.c
 *   @brief  Check testsuite for clustercon functions
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  20/03/2022
 *      Revision:  none
 * Last modified:  2024-11-13 19:20
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <check.h>
#include <stdlib.h>
#include "checktools.inc"

#include "clustercon.c"

/** Dummy test to trigger fixtures
 *
 * This test is defined and added to all testcases in order to execute at
 * least one test test in each testcase of the testsuite, trigger the
 * fixtures and have a decent coverage report.
 */
START_TEST(clustercon_test) {
    /* This test is supposed to trigger a SIGABRT(6) and will crash the
     * whole testsuite if not caught or not in a child process */
    forktest_only;

    abort();
}
END_TEST

/************************************************************************/
/* Begining of test (potentially in child) */
void clustercon_checked_uninitialized_setup() {
    signals_catch();
    forktest_gprofdir();
}

/* End of test (potentially in child) */
void clustercon_checked_uninitialized_teardown() {
    signals_release();
}
/************************************************************************/
void clustercon_unchecked_common_setup() {
    forktest_init();
}
void clustercon_unchecked_common_teardown() {
}
/************************************************************************/
Suite* clustercon_suite() {
    Suite *s;
    TCase *tc;

    s = suite_create("Clustercon");

    tc = tcase_create("ClusterconUninitialized");
    tcase_set_tags(tc,"ClusterconTag ClusterconTag2");
    /* tcase_set_timeout(tc,5); */ /* seconds */
    tcase_add_checked_fixture(tc, clustercon_checked_uninitialized_setup, clustercon_checked_uninitialized_teardown);
    tcase_add_unchecked_fixture(tc, clustercon_unchecked_common_setup, clustercon_unchecked_common_teardown);
    suite_add_tcase(s, tc);
    tcase_add_test_raise_signal(tc, clustercon_test,6);

    return s;
}
/* vim: set tw=80: */
